@@ -35,6 +35,8 @@
 #include <kwindowsystem.h>
 #include <KWindowSystem/KWindowInfo>
 
+#include <kquickaddons/quickviewsharedengine.h>
+
 #include <kwindoweffects.h>
 #include <Plasma/Plasma>
 #include <Plasma/Corona>
@@ -307,7 +309,7 @@ void DialogPrivate::updateVisibility(bool visible)
         } else {
             q->setFlags(Qt::FramelessWindowHint | q->flags());
         }
-        if (type == Dialog::Dock) {
+        if (type == Dialog::Dock || type == Dialog::Notification || type == Dialog::OnScreenDisplay) {
             KWindowSystem::setOnAllDesktops(q->winId(), true);
         } else {
             KWindowSystem::setOnAllDesktops(q->winId(), false);
@@ -673,6 +675,8 @@ Dialog::Dialog(QQuickItem *parent)
     property("data");
     //Create the FrameSvg background.
     d->frameSvgItem = new Plasma::FrameSvgItem(contentItem());
+    //This is needed as a transition thing for KWayland
+    setProperty("__plasma_frameSvg", QVariant::fromValue(d->frameSvgItem->frameSvg()));
 
     connect(&d->theme, SIGNAL(themeChanged()),
             this, SLOT(updateTheme()));
@@ -998,7 +1002,7 @@ void Dialog::setType(WindowType type)
         }
     }
 
-    if (type == Dock) {
+    if (type == Dock || type == Notification || type == OnScreenDisplay) {
         KWindowSystem::setOnAllDesktops(winId(), true);
     } else {
         KWindowSystem::setOnAllDesktops(winId(), false);
@@ -1038,7 +1042,9 @@ void Dialog::focusOutEvent(QFocusEvent *ev)
         const QWindow *focusWindow = QGuiApplication::focusWindow();
         bool childHasFocus = focusWindow && ((focusWindow->isActive() && isAncestorOf(focusWindow)) || focusWindow->type() & Qt::Popup);
 
-        if (qobject_cast<const View *>(focusWindow) || (!parentHasFocus && !childHasFocus)) {
+        const bool viewClicked = qobject_cast<const KQuickAddons::QuickViewSharedEngine *>(focusWindow) || qobject_cast<const View *>(focusWindow);
+
+        if (viewClicked || (!parentHasFocus && !childHasFocus)) {
             setVisible(false);
             emit windowDeactivated();
         }
